Guides
======

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   guides/search.rst
   guides/archive.rst
   guides/download.rst
   guides/feed_website_monitor.rst
   guides/authentication.rst
   guides/captcha.rst
